@@ -1,5 +1,5 @@
 dnb_get_url <- function(path, query, limit, start) {
-	req <- GET("http://services.dnb.de/", path=path, query=list(version="1.1", operation="searchRetrieve", query=query, maximumRecords=limit, startRecord=start, recordSchema="MARC21-xml"))
+	req <- GET("https://services.dnb.de/", path=path, query=list(version="1.1", operation="searchRetrieve", query=query, maximumRecords=limit, startRecord=start, recordSchema="MARC21-xml"))
 	dnb_check(req)
 	if(getOption("rdnb_show_url")) message("Request: ", req$url)
 	return(req)
@@ -37,7 +37,7 @@ dnb_to_df <- function(lst, clean) {
 		
 		if(!is.null(rec[["001"]])) {	# id/link
 			df$id[r] <- rec[["001"]]
-			df$link[r] <- paste0("http://d-nb.info/", rec[["001"]])	
+			df$link[r] <- paste0("https://d-nb.info/", rec[["001"]])	
 		}
 		if(!is.null(rec[["100"]][["subfield.a"]])) {	# author
 			aut <- rec[["100"]][["subfield.a"]]
